Learn R Programming

qcauchyreg (version 1.0)

Poverty: Percentage of extremely poor.

Description

Percentage of extremely poor, by Brazilian municipality for the year 2010. Data made available by http://www.atlasbrasil.org.br/.

Usage

data("Poverty")

Arguments

Format

A data frame containing 5501 observations on 4 variables.

poverty

Percentage of extremely poor, by Brazilian municipality for the year 2010.

population

Total municipal population in 2010, in thousands.

illiteracy

Municipal illiteracy rate of people aged 15 or over, in 2010.

pc_income

Municipal per capita income (in Brazilian reais), in 2010.

Details

The dataset is available at http://www.atlasbrasil.org.br/. The data refer to 5501 Brazilian municipalities observed in 2010. The dependent variable is the percentage of people in extreme poverty (poverty). Naturally, it is a limited variable that takes values in the unit range. The explanatory variables are total population in thousands of people (population), illiteracy rate of people aged 15 or over (illiteracy) and per capita income in Brazilian reais (pc_income). Municipalities with missing information on any of the variables were excluded from the sample.

Examples

Run this code

data("Poverty", package = "qcauchyreg")

reg <- qcreg(poverty ~ population + illiteracy + pc_income, data = Poverty, npi=50)
summary(reg)
reg$effects

plot(reg$pis, type="l")

plot(reg$quantregplot)

Run the code above in your browser using DataLab